@@ -1,11 +1,11 @@
 use prost::Message;
 use std::fmt::{Debug, Error, Formatter};
 
-pub struct Debuggable<'a>(Box<&'a dyn Message>);
+pub struct Debuggable<'a>(&'a dyn Message);
 
 impl<'a> Debuggable<'a> {
     pub fn from(message: &'a dyn Message) -> Self {
-        Debuggable(Box::from(message))
+        Debuggable(message)
     }
 }
 
